<p align="center"><img src="https://github.com/PKSHATechnology-Research/camphr/blob/master/img/logoc.svg" width="200" /></p>

# Camphr - spaCy plugin for Transformers, Udify, Elmo, etc.

[![Documentation Status](https://readthedocs.org/projects/camphr/badge/?version=latest)](https://camphr.readthedocs.io/en/latest/?badge=latest)
![](https://github.com/PKSHATechnology-Research/camphr/workflows/test/badge.svg)
![](https://github.com/PKSHATechnology-Research/camphr/workflows/test%20extras/badge.svg)
![](https://github.com/PKSHATechnology-Research/camphr/workflows/test%20package/badge.svg)

Camphr is a *Natural Language Processing* library that helps in seamless integration for a wide variety of techniques from state-of-the-art to conventional ones.
You can use [Transformers](https://huggingface.co/transformers/) ,  [Udify](https://github.com/Hyperparticle/udify), [ELmo](https://allennlp.org/elmo), etc. on [spaCy](https://github.com/explosion/spaCy).

Check the [documentation](https://camphr.readthedocs.io/en/latest/) for more information

# License

Camphr is licensed under [Apache 2.0](./LICENSE).
